@@ -19,6 +19,8 @@ addDictCases("Failų stebėtojas", "Failų stebėtojo", "Failų stebėtojui", "F
 addDictCases("Gauta žinutė", "Gautos žinutės", "Gautai žinutei", "Gautą žinutę", "Gauta žinute", "Gautoje žinutėje");
 addDictCases("Gyvybė", "Gyvybės", "Gyvybei", "Gyvybę", "Gyvybe", "Gyvybėje");
 addDictCases("Greitas paleidimas", "Greito paleidimo", "Greitam paleidimui", "Greitą paleidimą", "Greitu paleidimu", "Greitame paleidime");
+addDictCases("Greitųjų žinučių kontaktas", "Greitųjų žinučių kontakto", "Greitųjų žinučių kontaktui", "Greitųjų žinučių kontaktą", "Greitųjų žinučių kontaktu", "Greitųjų žinučių kontakte");
+addDictCases("Greitųjų žinučių buvimas", "Greitųjų žinučių buvimo", "Greitųjų žinučių buvimui", "Greitųjų žinučių buvimą", "Greitųjų žinučių buvimu", "Greitųjų žinučių buvime");
 addDictCases("Įvesties metodo skydelis", "Įvesties metodo skydelio", "Įvesties metodo skydeliui", "Įvesties metodo skydelį", "Įvesties metodo skydeliu", "Įvesties metodo skydelyje");
 addDictCases("Kalendorius", "Kalendoriaus", "Kalendoriui", "Kalendorių", "Kalendoriu", "Kalendoriuje");
 addCapitalDictCases("KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra");
@@ -70,6 +72,7 @@ addDictCases("Simbolių parinkiklis", "Simbolių parinkiklio", "Simbolių parink
 addDictCases("Sistemos apkrovos žiūriklis", "Sistemos apkrovos žiūriklio", "Sistemos apkrovos žiūrikliui", "Sistemos apkrovos žiūriklį", "Sistemos apkrovos žiūrikliu", "Sistemos apkrovos žiūriklyje");
 addDictCases("Sistemos dėklas", "Sistemos dėklo", "Sistemos dėklui", "Sistemos dėklą", "Sistemos dėklu", "Sistemos dėkle");
 addDictCases("Sistemos stebėtojas", "Sistemos stebėtojo", "Sistemos stebėtojui", "Sistemos stebėtoją", "Sistemos stebėtoju", "Sistemos stebėtojuje");
+addDictCases("Socialinės naujienos", "Socialinių naujienų", "Socialinėms naujienoms", "Socialines naujienas", "Socialinėms naujienoms", "Socialinėse naujienose");
 addDictCases("Skaičiuotuvas", "Skaičiuotuvo", "Skaičiuotuvui", "Skaičiuotuvą", "Skaičiuotuvu", "Skaičiuotuve");
 addDictCases("Skaitmeninis laikrodis", "Skaitmeninio laikrodžio", "Skaitmeniniui laikrodžiui", "Skaitmeninį laikrodį", "Skaitmeniniu laikrodžiu", "Skaitmeniniame laikrodyje");
 addDictCases("Skydelis", "Skydelio", "Skydeliui", "Skydelį", "Skydeliu", "Skydelyje");
